@@ -2,11 +2,9 @@ import os, json
 
 import appdirs
 
+
 name = "pydatasci"
 
-
-# ToDo - update the install documentation
-# ToDo - import this pds_config vartiable from MLdb script.
 app_dir = appdirs.user_data_dir()
 default_config_path = app_dir + "pydatasci_config.json"
 default_db_path = app_dir + "pydatasci_db.sqlite3"
@@ -22,7 +20,7 @@ def check_path_permissions(path:str):
 	elif not writeable:
 		print("\n=> Error - your operating system userID does not have permission to write to path:\n" + path + "\n")		
 	elif not readable or not writeable:
-		print("\n=> Fix - you can attempt to fix this by running `mldb.grant_appdirs_permissions()`.\n")
+		print("\n=> Fix - you can attempt to fix this by running `pds.grant_appdirs_permissions()`.\n")
 		return False
 	elif readable and writeable:
 		return True
@@ -36,13 +34,13 @@ def grant_appdirs_permissions():
 	try:
 		sys_response = os.system(full_command)
 	except:
-		print("\nError - error failed to execute this system command: " + full_command +"\n")
+		print("\n=> Error - error failed to execute this system command: " + full_command +"\n")
 	
 	permissions = check_path_permissions(path=app_dir)
 	if permissions == True:
-		print("\nSuccess - operating system userID can read and write from path: " + app_dir + "\n")
+		print("\n=> Success - operating system userID can read and write from path: " + app_dir + "\n")
 	else:
-		print("\nError - Failed to grant operating system userID permission to read and write from path: " + app_dir + "\n")
+		print("\n=> Error - Failed to grant operating system userID permission to read and write from path: " + app_dir + "\n")
 
 
 def get_config():
@@ -52,7 +50,7 @@ def get_config():
 			pds_config = json.load(pds_config_file)
 			return pds_config
 	else: 
-		print("\n Welcome - configuration not set, run `pds.create_config()` in Python shell.\n")
+		print("\n=> Welcome to pydatasci. Configuration not set, run `pds.create_config()` in Python shell.\n")
 
 
 def create_config():
@@ -62,7 +60,6 @@ def create_config():
 		if permissions:
 
 			pds_config = {
-				"app_dir": app_dir,
 				"config_path": default_config_path,
 				"db_path": default_db_path,
 			}
@@ -74,38 +71,46 @@ def create_config():
 				print("\n=> Error - failed to create config file at path:\n" + default_config_path)
 				print("===================================\n")
 				raise
-
-			# verify its creation
-			config_exists = os.path.exists(default_config_path)
-			if config_exists:
-				print("\n=> Success - created config file for settings at path:\n" + default_config_path + "\n")
-			else:
-				print("\n=> Error - failed to create config at path:\n" + default_config_path + "\n")
+			print("\n=> Success - created config file for settings at path:\n" + default_config_path + "\n")
 	else:
-		print("\n Warning - skipping as config file already exists at path: " + default_config_path + "\n")
+		print("\n=> Warning - skipping as config file already exists at path: " + default_config_path + "\n")
 
 
 def delete_config(confirm:bool):
-	if confirm:
-		config_exists = os.path.exists(default_config_path)
-
-		if config_exists:
+	pds_config = get_config()
+	if pds_config is None:
+		print("\n=> Warning - skipping as there is no config file to delete.\n")
+	else:
+		if confirm:
+			config_path = pds_config['config_path']
 			try:
-				os.remove(default_config_path)
+				os.remove(config_path)
 			except:
-				print("\n=> Error - failed to delete config file at path:\n" + default_config_path)
+				print("\n=> Error - failed to delete config file at path:\n" + config_path)
 				print("===================================\n")
 				raise
-			print("\n=> Success - deleted config file at path:\n" + default_config_path + "\n")
+			print("\n=> Success - deleted config file at path:\n" + config_path + "\n")		
 		else:
-			print("\n=> Warning - there is no file to delete at path:\n" + default_config_path + "\n")
+			print("\n=> Warning - skipping deletion because `confirm` arg not set to boolean `True`.\n")
+
+
+def update_config(kv:dict):
+	pds_config = get_config()
+	if pds_config is None:
+		print("\n=> Warning - there is no config file to update.\n")
 	else:
-		print("\n=> Warning - skipping deletion because `confirm` arg not set to boolean `True`.\n")
+		for k, v in kv.items():
+			pds_config[k] = v		
+		config_path = pds_config['config_path']
+		
+		try:
+			with open(config_path, 'w') as pds_config_file:
+				json.dump(pds_config, pds_config_file)
+		except:
+			print("\n=> Error - failed to update config file at path:\n" + config_path)
+			print("===================================\n")
+			raise
+		print("\n=> Success - updated configuration settings:\n" + str(pds_config) + "\n")
 
 
 pds_config = get_config()
-
-
-# update_config()?
-#dict? name str of param and value of param?
-#iter over each?
